import os

import pandas as pd


def read_excel(file_name, sheet_name='Sheet1'):
    df = pd.read_excel(file_name, sheet_name=sheet_name, dtype=object)
    for ele in df.values:
        yield ele


def get_excel_files(directory="."):
    """
    递归获取目录下的所有Excel文件（.xlsx, .xls）
    """
    excel_files = []
    for root, dirs, files in os.walk(directory):
        for file in files:
            if file.endswith(('.xlsx', '.xls')) and not file.startswith('~'):
                excel_files.append(os.path.join(root, file))
    return excel_files



import collections
import uuid

from common.service.medical_text import extract_all_relation_key, extract_medical_text, sentence_count, \
    random_pick_relation_key, extract_document_by, extract_medical_record_text_by_entity_uuid
from common.util.csv_util import write_csv
from common.util.database_connection_util import get_connection_by_schema
from common.util.date_util import current_time
from common.util.sql_util import store_by_batch
from common.util.string_util import cut_by_time


class TestSqlUtil:
    def test_extract_all_relation_key(self):
        pass
        # conn = get_tumour_stage_connection(b'')
        # cursor = conn.cursor()
        # relation_key_list = extract_all_relation_key(cursor)
        # for relation_key in relation_key_list:
        #     print(relation_key)

    def test_extract_medical_text(self):
        corpus_conn = get_connection_by_schema(b'my pleasure lord', 'nlp_corpus')
        cursor = corpus_conn.cursor()

        # doc_list = extract_document_by(cursor, '1011001', '854966', '2019-03-15 15:24:00', dataset_id='Dataset20240914rms001')
        doc = extract_medical_record_text_by_entity_uuid(cursor, "6402a865abebe9a2ee635eb1", 'ncpcs_nlp')

        print(doc.content)

    def test_sentence_count(self):
        sentence_list = ["测试", "测试", "四大皆空", "第三方i哦", "第三方i哦", "第三方i哦"]
        sentence_count(sentence_list)

    def test_random_pick_relation_key(self):
        conn = get_connection_by_schema(b'')
        cursor = conn.cursor()
        all_relation_key_list = extract_all_relation_key(cursor)
        relation_key_dict = collections.defaultdict(list)
        for relation_key in all_relation_key_list:
            relation_key_dict[relation_key.medical_institution_code].append(relation_key)
        assert len(random_pick_relation_key(relation_key_dict, 500)) == 500
        assert len(random_pick_relation_key(relation_key_dict, 37)) == 37




import pkuseg

from common.util.string_util import any_match, any_match_bool, extract_digit, find_all, \
    remove_special_symbols, has_chinese, is_chinese, split_text, handle_short_sentence, locate_two_word, \
    clean_string, CHINESE_MATCH


class TestStringUtil:
    def test_any_match(self):
        result = any_match("快乐池塘栽种了梦想就变成海洋", ["快乐", "梦想", "海洋", "人生", "纱布"])
        assert result == ["快乐", "梦想", "海洋"]

    def test_any_match_bool(self):
        result = any_match_bool("快乐池塘栽种了梦想就变成海洋", ["快乐", "人生", "纱布"])
        assert result is True

    def test_extract_digit(self):
        result = extract_digit("快乐1池塘栽5种了梦想就9变成海洋")
        assert result == "159"

    def test_find_all(self):
        positions = find_all("快了1池塘栽5种了梦想就9变成海洋", '了')
        assert positions == [1, 8]

    def test_remove_special_symbols(self):
        result = remove_special_symbols("快乐池塘\n\r\b栽\t种了梦想就变成海\n洋")
        assert result == "快乐池塘栽种了梦想就变成海洋"

    def test_has_chinese(self):
        result = has_chinese("dis当ogiosdg")
        assert result is True
        result = has_chinese("disogiosdg")
        assert result is False

    def test_is_chinese(self):
        result = is_chinese("好")
        assert result is True
        result = is_chinese("1")
        assert result is False
        result = is_chinese("a")
        assert result is False
        result = is_chinese("+")
        assert result is False

    def test_handle_short_sentence(self):
        result = handle_short_sentence([(0, 10), (11, 14), (15, 30), (31, 39)])
        assert result == [(0, 14), (15, 30), (31, 39)]

    def test_locate_two_word(self):
        assert locate_two_word("神经母细胞瘤神经的镂空设计符合4期神经母细胞瘤收到反馈就是刘佳分4期是快乐的感觉", "神经母细胞瘤", "4期") == (0, 15)
        assert locate_two_word("神经母细胞瘤神经的镂空设计符合4期神经母细胞瘤收到反馈就是刘佳分4期是快乐的感觉", "神经母细胞瘤", "4期", keep_order=False) == (17, 15)

    def test_clean_string(self):
        assert clean_string("=458*双方今后的健康+", left_match_list=[CHINESE_MATCH], right_match_list=[CHINESE_MATCH]) == "双方今后的健康"

